@@ -102,8 +102,8 @@ def sendresults(url, _headers, data, timeout=65, stream=False):
             else:
                 r = "Session Error " + str(z)
                 logger.error(r)
-                logger.error(f"Response: {response.status_code}: {response.content}")
-                logger.error(f"Response content {response.content}")
+                logger.error(f'Response: {response.status_code}: {response.content}')
+                logger.error(f'Response content {response.content}')
                 if z < max_attempt:
                     logger.info(" Error try to get new session " + str(z) + "/5")
                     headers = inforlogin.reconnect()
